@@ -1,7 +1,7 @@
-from pywisc.wisc_base import Wisc
+from pywisc.wisc import Wisc
 
 
 def test_01():
-    df = 'test/test_wisc_01.json'
+    df = 'pywisc/data/wisc_4_es_ar.json'
     w = Wisc(definition_data=df)
     assert w.is_valid
\ No newline at end of file
